#!/bin/sh

# eLibera Server starter-script 1.0
# --------------------------------------------------------------
# here starts the basic server-start-up configuration

# the JAR-file-name of the server
JAR_NAME="mle_Messaging_Server_1_0.jar"
# the file name of the system-out log (console output)
SYSTEM_LOG_FILE="log_mleMessagingServer.log"
# maxmimum JAVA VM memory
XMX=512m
# startup JAVA VM memory
XMS=128m
# directory of the jar file, only change this, if this startup-script is in another directory
SERVER_DIR=/opt/mleserver/messaging-server/
# the current directory
CUR_DIR=`pwd`
# the directory where the configuration files are located, usually in the conf dir of the current directory
CONFIGURATION_DIR=$SERVERDIR"conf/"
# the name of the PID file, where the process ID of the server is stored
PIDFILE=messaging.pid
# the name of the server
SERVER_NAME="MLE Messaging Server 1.0"
# the time we wait for the server to start-up
WAIT_FOR_SERVER_STARTUP=5
# should we print the log file of the server start-up after the starting has finished
SHOW_LOG_AFTER_START_UP=true
# Do not change this value !
PROP_DIR_CONF_CLASS_PROPERTY="com.elibera.msgs.app.MessagingServer.settingsDIR"

# --------------------------------------------------------------
# here starts the script

cd $SERVER_DIR

start() {
	if test -f $PIDFILE
	then
		PID2=`cat $PIDFILE`
		echo "File $PIDFILE already exists, maybe another server instance is already running in the background with the PID:$PID2 ?"
		echo "You should defently check the \"$SYSTEM_LOG_FILE\"-log file (or run \"$CMD_LOG\") for a successfull start-up of the server!"
		rm $PIDFILE
	fi
	nohup \
	java -D$PROP_DIR_CONF_CLASS_PROPERTY=$CONFIGURATION_DIR \
		-server -XX:+UseBiasedLocking -XX:+UseParallelGC \
		-Xmx$XMX -Xms$XMS \
		-jar $JAR_NAME  > $SYSTEM_LOG_FILE &
	echo $! > $PIDFILE
	PID=`cat $PIDFILE`
	echo "Waiting $WAIT_FOR_SERVER_STARTUP seconds for Server start-up (PID:$PID) ..."
	sleep $WAIT_FOR_SERVER_STARTUP"s"
	ALIVE=`ps -p $PID | grep $PID`
	if [ "$SHOW_LOG_AFTER_START_UP" == "true" ]
	then 
		echo "The log of the server start-up:"
		echo "------------------------------------------------------------"
		cat $SYSTEM_LOG_FILE
		echo "------------------------------------------------------------"
	fi
	if [ "X$ALIVE" == "X" ]
	then
		echo "Start-up of $SERVER_NAME seems to have FAILED!"
		echo "Check the log for errors! (PID:$PID)"
	else 
		echo "$SERVER_NAME has been started! (PID:$PID)"
		echo "Run \"$CMD_LOG\" to see the log-file of the server for successful start-up!"
	fi
}
stop() {
	if test -f $PIDFILE
	then
		PID=`cat $PIDFILE`
		if [ "X$PID" != "X" ]
		then 
			kill -9 $PID
			rm $PIDFILE
			echo "$SERVER_NAME has been stoped! (PID:$PID)"
		else
			"$SERVER_NAME was not started? Empty PID-File ($PIDFILE) found!"
		fi
	else
		echo "$SERVER_NAME was not started? No PID-File ($PIDFILE) found!"
	fi
}
log() {
	cat $SYSTEM_LOG_FILE
}

CMD_LOG="$0 log"
case "$2" in
	fast)
		WAIT_FOR_SERVER_STARTUP=1
		;;
esac
case "$1" in	
	start)
		start
		;;
	stop)
		stop
		;;
	restart)
		stop
		start
		;;
	log)
		log
		;;
	*)	
		echo $"Usage: $0 {start|stop|restart|log}"
		RETVAL=1
esac
echo ""
exit $RETVAL	
